# Changelog

## Version 0.5.1
- Add ability to log your urls and tokens

## Version 0.5
- First public release
- Basic functionality
  - Upload to 0x0
  - Delete with specified token
  - Choose instance
  - upload stdin
  - Basic auth
  - config file
